==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.md <==
# AwsTransferFamilyAwsSftp


```text
aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp
```

```text
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')
```



| Illustration | AwsTransferFamilyAwsSftp | AwsTransferFamilyAwsSftpCard | AwsTransferFamilyAwsSftpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.png) | ![illustration for AwsTransferFamilyAwsSftp](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.Local.png) | ![illustration for AwsTransferFamilyAwsSftpCard](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftpCard.Local.png) | ![illustration for AwsTransferFamilyAwsSftpGroup](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftpGroup.Local.png) |




## AwsTransferFamilyAwsSftp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftp('AwsTransferFamilyAwsSftp', 'Aws Transfer Family Aws Sftp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftp('AwsTransferFamilyAwsSftp', 'Aws Transfer Family Aws Sftp', 'an optional tech label')
@enduml
```

## AwsTransferFamilyAwsSftpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpCard('AwsTransferFamilyAwsSftpCard', 'Aws Transfer Family Aws Sftp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpCard('AwsTransferFamilyAwsSftpCard', 'Aws Transfer Family Aws Sftp Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsSftpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpGroup('AwsTransferFamilyAwsSftpGroup', 'Aws Transfer Family Aws Sftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpGroup('AwsTransferFamilyAwsSftpGroup', 'Aws Transfer Family Aws Sftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.md <==
# AwsTransferFamilyAwsSftp


```text
aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp
```

```text
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')
```



| Illustration | AwsTransferFamilyAwsSftp | AwsTransferFamilyAwsSftpCard | AwsTransferFamilyAwsSftpGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.png) | ![illustration for AwsTransferFamilyAwsSftp](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp.Local.png) | ![illustration for AwsTransferFamilyAwsSftpCard](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftpCard.Local.png) | ![illustration for AwsTransferFamilyAwsSftpGroup](../../../aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftpGroup.Local.png) |




## AwsTransferFamilyAwsSftp

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftp('AwsTransferFamilyAwsSftp', 'Aws Transfer Family Aws Sftp', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftp
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftp('AwsTransferFamilyAwsSftp', 'Aws Transfer Family Aws Sftp', 'an optional tech label')
@enduml
```

## AwsTransferFamilyAwsSftpCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpCard('AwsTransferFamilyAwsSftpCard', 'Aws Transfer Family Aws Sftp Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpCard
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpCard('AwsTransferFamilyAwsSftpCard', 'Aws Transfer Family Aws Sftp Card', 'an optional description')
@enduml
```

## AwsTransferFamilyAwsSftpGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpGroup('AwsTransferFamilyAwsSftpGroup', 'Aws Transfer Family Aws Sftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AwsTransferFamilyAwsSftpGroup
include('aws-20210730/Resource/MigrationAndTransfer/AwsTransferFamilyAwsSftp')

' renders the element
AwsTransferFamilyAwsSftpGroup('AwsTransferFamilyAwsSftpGroup', 'Aws Transfer Family Aws Sftp Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
